@@ -232,11 +232,6 @@ my $data =
 				# FIXUP
 			},
 			
-		lonehash =>
-			{
-				# FIXUP
-			},
-			
 		nested =>
 			{
 				a =>
@@ -306,7 +301,7 @@ my $data =
 	};
 
 $data->{objects}->{$_} = TestObject->new($_, $data->{records}->{$_}) foreach (keys(%{$data->{records}}));
-$data->{lonehash} = { lonehash => $data->{records} };
+$data->{'nested-dpath'} = $data->{nested}; 
 
 my $tests =
 	{
@@ -748,63 +743,6 @@ QRY
 				},
 			],
 			
-		lonehash =>
-			[
-				{
-					q => 'key.REGEXP(.*)',
-					e => undef,		# FIXUP
-				},
-				{
-					q => 'key.REGEXP([dkob])',
-					e => [ qw(b d k o) ],
-				},
-
-				{
-					q => 'name.REGEXP/(?i)a/',
-					e => [ qw(a d f g h i j l m o p q r s u v w x y) ],
-				},
-				{
-					q => 'name.REGEXP/(?i)a/ AND siblings.>(1)',
-					e => [ qw(a f g j m o p q s u v w x) ],
-				},
-				{
-					q => 'name.REGEXP/(?i)a/ AND siblings.>(1) AND byear.<(1960)',
-					e => [ qw(a f g m p q s w) ],
-				},
-				{
-					q => 'name.REGEXP/(?i)a/ AND siblings.>(1) AND byear.<(1960) AND sex.REGEXP(M)',
-					e => [ qw(f m w) ],
-				},
-				{
-					q => 'name.REGEXP/(?i)a/ AND siblings.>(1) AND byear.<(1960) AND sex.REGEXP(M) AND city.REGEXP(z)',
-					e => [ qw(f m) ],
-				},
-				{
-					q => <<'QRY',
-						name.REGEXP/(?i)a/
-							AND
-						siblings.>(1)
-							AND
-						byear.<(1960)
-							AND
-						(
-							(
-								sex.REGEXP(M)
-									AND
-								city.REGEXP(z)
-							)
-								OR
-							(
-								sex.REGEXP(F)
-									AND
-								city.REGEXP(l)
-							)
-						)
-QRY
-					e => [ qw(a f m p s) ],
-				},
-			],
-			
 		nested =>
 			[
 				{
@@ -828,6 +766,34 @@ QRY
 					e => [ $data->{nested}->{a} ],
 				},
 			],
+
+		'nested-dpath' =>
+			[
+				{
+					q => 'path(//fee[value == 4])',
+					e => [ ],
+				},
+				{
+					q => 'path(//fee[value == 3])',
+					e => [ $data->{nested}->{c} ],
+				},
+				{
+					q => 'path(//fee[value == 3]) AND path(//foo/a[value == 30])',
+					e => [ $data->{nested}->{c} ],
+				},
+				{
+					q => 'path(//fee[value == 3]) AND path(//foo/a[value == 20])',
+					e => [ ],
+				},
+				{
+					q => 'path(/fie/*[value > 5])',
+					e => [ $data->{nested}->{b}, $data->{nested}->{c}],
+				},
+				{
+					q => 'path(/fie/*[value < 3]) OR path(/fie/*[value > 6])',
+					e => [ $data->{nested}->{a}, $data->{nested}->{c} ],
+				},
+			],
 	};
 
 my @recordValues;
@@ -838,10 +804,6 @@ my @objectValues;
 push(@objectValues, $data->{objects}->{$_}) foreach (sort(keys(%{$data->{objects}})));
 $tests->{objects}->[0]->{e} = [ map { $_->get_id() } @objectValues ];
 
-my @lonehashValues;
-push(@lonehashValues, $_) foreach (sort(keys(%{$data->{lonehash}->{lonehash}})));
-$tests->{lonehash}->[0]->{e} = \@lonehashValues;
-
 my $fieldAccessors =
 	{
 		records =>
@@ -874,25 +836,15 @@ my $fieldAccessors =
 					),
 			],	
 
-		lonehash =>
-			[
-				Grep::Query::FieldAccessor->new
-					(
-						{
-							key => sub { $_[0]->[0] },
-							name => sub { $_[0]->[1]->{name} },
-							byear => sub { $_[0]->[1]->{byear} },
-							siblings => sub { $_[0]->[1]->{siblings} },
-							city => sub { $_[0]->[1]->{city} },
-							sex => sub { $_[0]->[1]->{sex} },
-						}
-					),
-			],
-			
 		nested =>
 			[
 				undef
-			]
+			],
+
+		'nested-dpath' =>
+			[
+				undef
+			],
 	};
 	
 my $recordFieldAccessor = Grep::Query::FieldAccessor->new();
@@ -915,8 +867,8 @@ my $matchAdjustors =
 	{
 		records => sub { $_[0] },
 		objects => sub { [ map { $_->get_id() } @{$_[0]} ] },
-		lonehash => sub { [ sort(keys(%{$_[0]->[0]})) ] },
 		nested => sub { $_[0] },
+		'nested-dpath' => sub { $_[0] },
 	};
 
 sub getData
